:mod:`lck.django.common.templatetags.strings`
=============================================


.. automodule:: lck.django.common.templatetags.strings


Functions
----------

.. autofunction:: slugify

.. autofunction:: strike_empty

.. autofunction:: title

.. autofunction:: transliterate

